@@ -7,10 +7,27 @@ tape("scaleLinear() has the expected defaults", function(test) {
   test.deepEqual(s.domain(), [0, 1]);
   test.deepEqual(s.range(), [0, 1]);
   test.equal(s.clamp(), false);
+  test.equal(s.unknown(), undefined);
   test.deepEqual(s.interpolate()({array: ["red"]}, {array: ["blue"]})(0.5), {array: ["rgb(128, 0, 128)"]});
   test.end();
 });
 
+tape("scaleLinear(range) sets the range", function(test) {
+  var s = scale.scaleLinear([1, 2]);
+  test.deepEqual(s.domain(), [0, 1]);
+  test.deepEqual(s.range(), [1, 2]);
+  test.equal(s(0.5), 1.5);
+  test.end();
+});
+
+tape("scaleLinear(domain, range) sets the domain and range", function(test) {
+  var s = scale.scaleLinear([1, 2], [3, 4]);
+  test.deepEqual(s.domain(), [1, 2]);
+  test.deepEqual(s.range(), [3, 4]);
+  test.equal(s(1.5), 3.5);
+  test.end();
+});
+
 tape("linear(x) maps a domain value x to a range value y", function(test) {
   test.equal(scale.scaleLinear().range([1, 2])(0.5), 1.5);
   test.end();
@@ -28,9 +45,9 @@ tape("linear(x) ignores extra domain values if the range is smaller than the dom
   test.end();
 });
 
-tape("linear(x) maps an empty domain to the range start", function(test) {
-  test.equal(scale.scaleLinear().domain([0, 0]).range([1, 2])(0), 1);
-  test.equal(scale.scaleLinear().domain([0, 0]).range([2, 1])(1), 2);
+tape("linear(x) maps an empty domain to the middle of the range", function(test) {
+  test.equal(scale.scaleLinear().domain([0, 0]).range([1, 2])(0), 1.5);
+  test.equal(scale.scaleLinear().domain([0, 0]).range([2, 1])(1), 1.5);
   test.end();
 });
 
@@ -74,9 +91,9 @@ tape("linear.invert(y) maps a range value y to a domain value x", function(test)
   test.end();
 });
 
-tape("linear.invert(y) maps an empty range to the domain start", function(test) {
-  test.equal(scale.scaleLinear().domain([1, 2]).range([0, 0]).invert(0), 1);
-  test.equal(scale.scaleLinear().domain([2, 1]).range([0, 0]).invert(1), 2);
+tape("linear.invert(y) maps an empty range to the middle of the domain", function(test) {
+  test.equal(scale.scaleLinear().domain([1, 2]).range([0, 0]).invert(0), 1.5);
+  test.equal(scale.scaleLinear().domain([2, 1]).range([0, 0]).invert(1), 1.5);
   test.end();
 });
 
@@ -168,6 +185,15 @@ tape("linear.rangeRound(range) is an alias for linear.range(range).interpolate(i
   test.end();
 });
 
+tape("linear.unknown(value) sets the return value for undefined and NaN input", function(test) {
+  var s = scale.scaleLinear().unknown(-1);
+  test.equal(s(undefined), -1);
+  test.equal(s(NaN), -1);
+  test.equal(s("N/A"), -1);
+  test.equal(s(0.4), 0.4);
+  test.end();
+});
+
 tape("linear.clamp() is false by default", function(test) {
   test.equal(scale.scaleLinear().clamp(), false);
   test.equal(scale.scaleLinear().range([10, 20])(2), 30);
@@ -455,3 +481,16 @@ tape("linear.copy() returns a copy with changes to clamping are isolated", funct
   test.equal(x.clamp(), false);
   test.end();
 });
+
+tape("linear.copy() returns a copy with changes to the unknown value are isolated", function(test) {
+  var x = scale.scaleLinear(), y = x.copy();
+  x.unknown(2);
+  test.equal(x(NaN), 2);
+  test.equal(isNaN(y(NaN)), true);
+  test.equal(y.unknown(), undefined);
+  y.unknown(3);
+  test.equal(x(NaN), 2);
+  test.equal(y(NaN), 3);
+  test.equal(x.unknown(), 2);
+  test.end();
+});
